@@ -13,7 +13,7 @@ use nom::bytes::complete::tag;
 use nom::character::complete::{none_of, one_of};
 use nom::combinator::map;
 use nom::error::{ErrorKind, ParseError};
-use nom::multi::{many1, separated_list};
+use nom::multi::{many1, separated_list0};
 use nom::sequence::tuple;
 use nom::IResult;
 use regex::Regex;
@@ -434,7 +434,7 @@ where
     let p_non_var = map(many1(none_of(" $")), join_chars);
     let p_arg = map(many1(alt((p_var, p_non_var))), join_str);
     let p_whitespace = many1(one_of(" \t"));
-    let p_args = separated_list(p_whitespace, p_arg);
+    let p_args = |s| separated_list0(p_whitespace, p_arg)(s);
     let result: IResult<&str, Vec<OsString>> = (p_args)(command);
     result.expect("Parse error").1
 }
